*********
Changelog
*********

=============
Version 0.9.9
=============

* Added -a/--anchor option to exquires-correlate
* Added superior error handling
* Improved ratio parsing
* Reformatted documentation

===============
Version 0.9.8.3
===============

* Modified matrix formatting for exquires-correlate

===============
Version 0.9.8.2
===============

* Important bugfix for exquires-update

===============
Version 0.9.8.1
===============

* Added -l/--linear option to eanbqh.py

=============
Version 0.9.8
=============

* Major code revision (10/10 pylint score)
* Added Spearman's rank cross-correlation

=============
Version 0.9.7
=============

* Initial public release
